@@ -12,34 +12,26 @@ class Action(enum.Enum):
     UPDATE = "update"
 
 
-def render_turbo_stream(action, target, content=""):
+def render_turbo_stream(action: Action, target: str, content: str = "") -> str:
     """Wraps content in correct <turbo-stream> tags.
 
     :param action: action type
     :param target: the DOM ID target of the stream
     :param content: content to be wrapped. Can be empty.
 
-    :type action: turbo_response.Action
-    :type target: str
-    :type content: str
-
     :return: *<turbo-stream>* string
-    :rtype: str
-
     """
     return f'<turbo-stream action="{action.value}" target="{target}"><template>{content.strip()}</template></turbo-stream>'
 
 
-def render_turbo_frame(dom_id, content=""):
+def render_turbo_frame(dom_id: str, content: str = "") -> str:
     """
 
     Wraps a response in correct *<turbo-frame>* tags.
 
     :param dom_id: a DOM ID present in the content
     :param content: content of the turbo-frame
-    :type dom_id: str
-    :type content: str
 
-    :rtype: str
+    :return: *<turbo-frame>* string
     """
     return f'<turbo-frame id="{dom_id}">{content.strip()}</turbo-frame>'
